@@ -368,8 +368,8 @@ static fsal_status_t create_handle(struct fsal_export *export_pub,
 		return ceph2fsal_error(rc);
 
 	rc = fsal_ceph_ll_getattr(export->cmount, i, &stx,
-				  attrs_out ? CEPH_STATX_ATTR_MASK :
-					      CEPH_STATX_HANDLE_MASK,
+				  attrs_out ? CEPH_STATX_ATTR_MASK
+					    : CEPH_STATX_HANDLE_MASK,
 				  &op_ctx->creds);
 	if (rc < 0)
 		return ceph2fsal_error(rc);
@@ -408,8 +408,15 @@ static fsal_status_t get_fs_dynamic_info(struct fsal_export *export_pub,
 	int rc = 0;
 	/* Filesystem stat */
 	struct statvfs vfs_st;
+	/* The private 'full' object handle */
+	struct ceph_handle *handle =
+		container_of(obj_hdl, struct ceph_handle, handle);
 
-	rc = ceph_ll_statfs(export->cmount, export->root->i, &vfs_st);
+	/* Pass the inode for the obj_handle as the basis for the statfs.
+	 * If the inode is within a sub-volume, cephfs will report the correct
+	 * sub-volume quota.
+	 */
+	rc = ceph_ll_statfs(export->cmount, handle->i, &vfs_st);
 
 	if (rc < 0)
 		return ceph2fsal_error(rc);
@@ -478,6 +485,25 @@ void get_fsal_obj_hdl(struct fsal_export *exp_hdl, struct fsal_fd *fd,
 	*handle = &myself->handle;
 }
 
+static attrmask_t fs_supported_attrs(struct fsal_export *exp_hdl)
+{
+	attrmask_t supported_mask;
+	struct ceph_export *export;
+
+	export = container_of(exp_hdl, struct ceph_export, export);
+	supported_mask = fsal_supported_attrs(&exp_hdl->fsal->fs_info);
+
+	/* Fixup supported_mask to indicate if ACL is actually supported for
+	 * this export.
+	 */
+	if (export->use_acl)
+		supported_mask |= ATTR_ACL;
+	else
+		supported_mask &= ~ATTR_ACL;
+
+	return supported_mask;
+}
+
 /**
  * @brief Set operations for exports
  *
@@ -501,6 +527,7 @@ void export_ops_init(struct export_ops *ops)
 #ifdef CEPHFS_POSIX_ACL
 	ops->fs_acl_support = fs_acl_support;
 #endif /* CEPHFS_POSIX_ACL */
+	ops->fs_supported_attrs = fs_supported_attrs;
 #ifdef CEPH_PNFS
 	export_ops_pnfs(ops);
 #endif /* CEPH_PNFS */
