@@ -67,6 +67,7 @@ struct ceph_fsal_module {
 	bool client_oc;
 	bool async;
 	bool zerocopy;
+	bool use_old_uuid;
 };
 extern struct ceph_fsal_module CephFSM;
 
@@ -115,6 +116,7 @@ struct ceph_export {
 	char *fs_name; /* filesystem name */
 	char *cmount_path; /* path to cmount at */
 	int64_t fscid; /* Cluster fsid for named fs' */
+	bool use_acl; /* indicate ACL is supported */
 };
 
 struct ceph_fd {
@@ -253,6 +255,7 @@ int ceph_get_acl(struct ceph_export *export, struct ceph_handle *objhandle,
 #endif /* CEPHFS_POSIX_ACL */
 
 extern pthread_rwlock_t cmount_lock;
+extern struct avltree avl_cmount;
 
 void ceph_mount_init(void);
 struct ceph_mount *ceph_mount_lookup(const struct avltree_node *key);
