@@ -67,12 +67,12 @@ liz_context_t *lzfs_fsal_create_context(liz_t *instance, struct user_cred *cred)
 	}
 
 	liz_context_t *ctx;
-	uid_t uid = (cred->caller_uid == op_ctx->export_perms.anonymous_uid) ?
-			    0 :
-			    cred->caller_uid;
-	gid_t gid = (cred->caller_gid == op_ctx->export_perms.anonymous_gid) ?
-			    0 :
-			    cred->caller_gid;
+	uid_t uid = (cred->caller_uid == op_ctx->export_perms.anonymous_uid)
+			    ? 0
+			    : cred->caller_uid;
+	gid_t gid = (cred->caller_gid == op_ctx->export_perms.anonymous_gid)
+			    ? 0
+			    : cred->caller_gid;
 
 	ctx = liz_create_user_context(uid, gid, 0, 0);
 	if (!ctx) {
@@ -112,9 +112,8 @@ fsal_staticfsinfo_t *lzfs_fsal_staticinfo(struct fsal_module *module_hdl)
 	return &lzfs_module->fs_info;
 }
 
-struct lzfs_fsal_handle *
-lzfs_fsal_new_handle(const struct stat *attr,
-		     struct lzfs_fsal_export *lzfs_export)
+struct lzfs_fsal_handle *lzfs_fsal_new_handle(
+	const struct stat *attr, struct lzfs_fsal_export *lzfs_export)
 {
 	struct lzfs_fsal_handle *result = NULL;
 
