@@ -242,9 +242,9 @@ int nfs3_write(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 
 	LogNFS3_Operation(COMPONENT_NFSPROTO, req, &arg->arg_write3.file,
 			  " start: %" PRIx64 " len: %zu %s", offset, size,
-			  arg->arg_write3.stable == UNSTABLE ? "UNSTABLE" :
-			  arg->arg_write3.stable == UNSTABLE ? "DATA_SYNC" :
-							       "FILE_SYNC");
+			  arg->arg_write3.stable == UNSTABLE   ? "UNSTABLE"
+			  : arg->arg_write3.stable == UNSTABLE ? "DATA_SYNC"
+							       : "FILE_SYNC");
 
 	/* to avoid setting it on each error case */
 	resfail->file_wcc.before.attributes_follow = false;
@@ -265,7 +265,10 @@ int nfs3_write(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 
 	if (FSAL_IS_ERROR(fsal_status)) {
 		res->res_write3.status = nfs3_Errno_status(fsal_status);
-		goto return_ok;
+		if (nfs_RetryableError(fsal_status.major))
+			goto drop_error;
+		else
+			goto return_ok;
 	}
 
 	/* Sanity check: write only a regular file */
@@ -302,11 +305,10 @@ int nfs3_write(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 			     offset, size, MaxOffsetWrite);
 
 		if ((offset + size) > MaxOffsetWrite) {
-			LogEvent(
-				COMPONENT_NFSPROTO,
-				"A client tried to violate max file size %" PRIu64
-				" for exportid #%hu",
-				MaxOffsetWrite, op_ctx->ctx_export->export_id);
+			LogEvent(COMPONENT_NFSPROTO,
+				 "A client tried to violate max file size %" PRIu64
+				 " for exportid #%hu",
+				 MaxOffsetWrite, op_ctx->ctx_export->export_id);
 
 			res->res_write3.status = NFS3ERR_FBIG;
 
@@ -340,7 +342,10 @@ int nfs3_write(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 	/* Check for delegation conflict. */
 	if (state_deleg_conflict(obj, true)) {
 		res->res_write3.status = NFS3ERR_JUKEBOX;
-		goto return_ok;
+		if (nfs_DropDelayErrors())
+			goto drop_error;
+		else
+			goto return_ok;
 	}
 
 	/* Set up args, allocate from heap, iov_count will be 1 */
@@ -411,6 +416,13 @@ return_ok:
 	server_stats_io_done(size, 0, true, true);
 
 	return NFS_REQ_OK;
+
+drop_error:
+
+	obj->obj_ops->put_ref(obj);
+
+	server_stats_io_done(size, 0, false, true);
+	return NFS_REQ_DROP;
 } /* nfs3_write */
 
 /**
