@@ -45,6 +45,7 @@
 #include "nfs_creds.h"
 #include "pnfs_utils.h"
 #include <time.h>
+#include "nfs_qos.h"
 
 #include "gsh_lttng/gsh_lttng.h"
 #if defined(USE_LTTNG) && !defined(LTTNG_PARSING)
@@ -713,12 +714,11 @@ enum nfs_req_result complete_op(compound_data_t *data, nfsstat4 *status,
 
 	data->resp_size += sizeof(nfs_opnum4) + data->op_resp_size;
 
-	LogDebug(
-		COMPONENT_NFS_V4,
-		"Status of %s in position %d = %s, op response size is %" PRIu32
-		" total response size is %" PRIu32,
-		data->opname, data->oppos, nfsstat4_to_str(*status),
-		data->op_resp_size, data->resp_size);
+	LogDebug(COMPONENT_NFS_V4,
+		 "Status of %s in position %d = %s, op response size is %" PRIu32
+		 " total response size is %" PRIu32,
+		 data->opname, data->oppos, nfsstat4_to_str(*status),
+		 data->op_resp_size, data->resp_size);
 
 	if (result == NFS_REQ_ERROR) {
 		/* An error occurred, we do not manage the other requests
@@ -751,6 +751,12 @@ enum nfs_req_result process_one_op(compound_data_t *data, nfsstat4 *status)
 	enum nfs_req_result result;
 	COMPOUND4res *res_compound4;
 
+#ifdef ENABLE_QOS
+	if ((data->qos_flags & IS_QOS_IOPS_ACCOUNTED) == false) {
+		if (qos_process_iops(data) == QOS_TASK_SUSPENDED)
+			return NFS_REQ_ASYNC_WAIT;
+	}
+#endif
 	res_compound4 = &data->res->res_compound4_extended->res_compound4;
 
 	/* Used to check if OP_SEQUENCE is the first operation */
@@ -806,8 +812,8 @@ enum nfs_req_result process_one_op(compound_data_t *data, nfsstat4 *status)
 			   "DESTROY_SESSION in position %u out of 0-%" PRIi32
 			   " %s is %s",
 			   data->oppos, data->argarray_len - 1,
-			   session_compare ? "same session as SEQUENCE" :
-					     "different session from SEQUENCE",
+			   session_compare ? "same session as SEQUENCE"
+					   : "different session from SEQUENCE",
 			   bad_pos ? "not last op in compound" : "opk");
 
 		if (bad_pos) {
@@ -918,8 +924,9 @@ void set_slot_last_req(compound_data_t *data)
 {
 	struct timespec curr_time;
 
-	data->slot->last_req.opcode_num = get_nfs4_opcodes(
-		data, data->slot->last_req.opcodes, NFS4_MAX_OPERATIONS);
+	data->slot->last_req.opcode_num =
+		get_nfs4_opcodes(data, data->slot->last_req.opcodes,
+				 NFS4_MAX_OPERATIONS);
 	data->slot->last_req.xid = data->req->rq_msg.rm_xid;
 	data->slot->last_req.seq_id = data->sequence;
 	now(&curr_time);
@@ -1063,6 +1070,20 @@ static enum xprt_stat nfs4_compound_resume(struct svc_req *req)
 	/* Restore the op_ctx */
 	resume_op_context(&reqdata->op_context);
 
+	/* IOPS IO should excecute previous function,
+	 * due to the wait its tapped*/
+#ifdef ENABLE_QOS
+	if ((data->qos_flags & IS_QOS_COMPOUND_IO) != false) {
+		/* reset the QOS COMPOUND */
+		LogFullDebug(COMPONENT_QOS,
+			     "Resetting the IS_QOS_COMPOUND_IO bits oppos: %d",
+			     data->oppos);
+		data->qos_flags &= ~IS_QOS_COMPOUND_IO;
+		data->oppos -= 1;
+		result = NFS_REQ_OK;
+		goto qos_resume_compound;
+	}
+#endif
 	/* Start by resuming the operation that suspended. */
 	result = (optabv4[data->opcode].resume)(&data->argarray[data->oppos],
 						data,
@@ -1082,6 +1103,9 @@ static enum xprt_stat nfs4_compound_resume(struct svc_req *req)
 		return XPRT_SUSPEND;
 	}
 
+#ifdef ENABLE_QOS
+qos_resume_compound:
+#endif
 	/* Skip the resumed op and continue through the rest of the compound. */
 	for (data->oppos += 1;
 	     result == NFS_REQ_OK && data->oppos < data->argarray_len;
@@ -1282,10 +1306,9 @@ int nfs4_Compound(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 
 	/* Check for too long request */
 	if (argarray_len > NFS4_MAX_OPERATIONS) {
-		LogMajor(
-			COMPONENT_NFS_V4,
-			"A COMPOUND with too many operations (%d) was received",
-			argarray_len);
+		LogMajor(COMPONENT_NFS_V4,
+			 "A COMPOUND with too many operations (%d) was received",
+			 argarray_len);
 
 		res_compound4->status = NFS4ERR_RESOURCE;
 		res_compound4->resarray.resarray_len = 0;
@@ -1376,7 +1399,9 @@ int nfs4_Compound(nfs_arg_t *arg, struct svc_req *req, nfs_res_t *res)
 	 * request might have already been resumed on another worker thread.
 	 */
 	data->req->rq_resume_cb = nfs4_compound_resume;
-
+#ifdef ENABLE_QOS
+	data->qos_flags = 0;
+#endif
 	/**********************************************************************
 	 * Now start processing the compound ops.
 	 **********************************************************************/
@@ -1423,9 +1448,9 @@ void nfs4_Compound_FreeOne(nfs_resop4 *res)
 {
 	int opcode;
 
-	opcode = (res->resop != NFS4_OP_ILLEGAL) ?
-			 res->resop :
-			 0; /* opcode 0 for illegals */
+	opcode = (res->resop != NFS4_OP_ILLEGAL)
+			 ? res->resop
+			 : 0; /* opcode 0 for illegals */
 	optabv4[opcode].free_res(res);
 }
 
@@ -1706,4 +1731,31 @@ bool xdr_COMPOUND4res_extended(XDR *xdrs, struct COMPOUND4res_extended **objp)
 	return xdr_COMPOUND4res(xdrs, &res_compound4_extended->res_compound4);
 }
 
+#ifdef ENABLE_QOS
+/**
+ * @brief Callback function for NFS4 compound operations.
+ *
+ * This function is called when a rate-controlled IOPS I/O needs to be resumed.
+ * It checks whether the operation was subject to rate limiting.
+ *
+ * @param args Pointer to qos_op_cb_arg structure containing callback arguments
+ */
+void nfs4_qos_compound_cb(void *args)
+{
+	struct qos_op_cb_arg *qos_cb_args = args;
+	compound_data_t *data = qos_cb_args->caller_data;
+
+	if (qos_cb_args->ratecontrol) {
+		LogFullDebug(COMPONENT_QOS, "Ratecontrol IO exit data: %p",
+			     data);
+		data->qos_flags |= IS_QOS_COMPOUND_IO;
+		svc_resume(data->req);
+
+	} else {
+		LogFullDebug(COMPONENT_QOS, "Ratecontrol IO exit data: %p",
+			     data);
+	}
+	gsh_free(args);
+}
+#endif
 /* @} */
