@@ -46,31 +46,6 @@
 #include "gsh_lttng/generated_traces/nfs4.h"
 #endif
 
-int get_raddr(SVCXPRT *xprt)
-{
-	sockaddr_t *ss = svc_getrpclocal(xprt);
-	int addr = 0;
-
-	if (ss == NULL)
-		return addr;
-
-	switch (ss->ss_family) {
-	case AF_INET6: {
-		void *ab =
-			&(((struct sockaddr_in6 *)ss)->sin6_addr.s6_addr[12]);
-		addr = ntohl(*(uint32_t *)ab);
-	} break;
-	case AF_INET:
-		addr = ntohl(((struct sockaddr_in *)ss)->sin_addr.s_addr);
-
-		break;
-	default:
-		break;
-	}
-
-	return addr;
-}
-
 /* spi_ops (spo_must_enforce bitmap + spo_must_allow bitmap) + 4 spi_ fields +
  * len
  */
@@ -112,7 +87,7 @@ enum nfs_req_result nfs4_op_exchange_id(struct nfs_argop4 *op,
 	char *temp;
 	bool update;
 	uint32_t server_pnfs_flags = 0;
-	in_addr_t server_addr = 0;
+	sockaddr_t *server_addr = 0;
 	/* Arguments and response */
 	EXCHANGE_ID4args *const arg_EXCHANGE_ID4 =
 		&op->nfs_argop4_u.opexchange_id;
@@ -122,7 +97,8 @@ enum nfs_req_result nfs4_op_exchange_id(struct nfs_argop4 *op,
 	EXCHANGE_ID4resok *const res_EXCHANGE_ID4_ok =
 		&resp->nfs_resop4_u.opexchange_id.EXCHANGE_ID4res_u.eir_resok4;
 	uint32_t resp_size = EXCHANGE_ID_BASE_RESP_SIZE;
-	int owner_len, scope_len;
+	int owner_len, scope_len, major_id_len;
+	char ipname[SOCK_NAME_MAX];
 
 	GSH_AUTO_TRACEPOINT(
 		nfs4, op_exchange_id_start, TRACE_INFO,
@@ -212,7 +188,7 @@ enum nfs_req_result nfs4_op_exchange_id(struct nfs_argop4 *op,
 	update = (arg_EXCHANGE_ID4->eia_flags &
 		  EXCHGID4_FLAG_UPD_CONFIRMED_REC_A) != 0;
 
-	server_addr = get_raddr(data->req->rq_xprt);
+	server_addr = svc_getrpclocal(data->req->rq_xprt);
 
 	/* Do we already have one or more records for client id (x)? */
 	client_record = get_client_record(
@@ -408,11 +384,29 @@ return_ok:
 	res_EXCHANGE_ID4_ok->eir_state_protect.spr_how =
 		unconf->cid_state_protect_how;
 
-	temp = gsh_malloc(owner_len + 1);
+	if (nfs_param.nfsv4_param.virtual_server) {
+		if (!sprint_sockip(server_addr, ipname, sizeof(ipname)))
+			(void)strlcpy(ipname, "<unknown>", sizeof(ipname));
+
+		major_id_len = owner_len + strlen(ipname);
+	} else {
+		major_id_len = owner_len;
+	}
+
+	temp = gsh_malloc(major_id_len + 1);
+
+	/* Copy cid_server_owner plus terminating NUL */
 	memcpy(temp, cid_server_owner, owner_len + 1);
 
+	LogDebug(COMPONENT_CLIENTID, "EXCHNAGE_ID major_id %s", temp);
+
+	if (nfs_param.nfsv4_param.virtual_server) {
+		/* Copy ipname + terminating NUL */
+		memcpy(temp + owner_len, ipname, major_id_len - owner_len + 1);
+	}
+
 	res_EXCHANGE_ID4_ok->eir_server_owner.so_major_id.so_major_id_len =
-		owner_len;
+		major_id_len;
 	res_EXCHANGE_ID4_ok->eir_server_owner.so_major_id.so_major_id_val =
 		temp;
 
