@@ -112,12 +112,13 @@ static void nfs4_recovery_load_clids(nfs_grace_start_t *gsp);
 static void nfs_release_nlm_state(char *release_ip);
 static void nfs_release_v4_clients(char *ip);
 
-clid_entry_t *nfs4_add_clid_entry(char *cl_name)
+clid_entry_t *nfs4_add_clid_entry(char *cl_name, bool reclaim_complete)
 {
 	clid_entry_t *new_ent = gsh_malloc(sizeof(clid_entry_t));
 
 	glist_init(&new_ent->cl_rfh_list);
 	(void)strlcpy(new_ent->cl_name, cl_name, sizeof(new_ent->cl_name));
+	new_ent->cl_reclaim_complete = reclaim_complete;
 	glist_add(&clid_list, &new_ent->cl_list);
 	++clid_count;
 	return new_ent;
@@ -301,7 +302,7 @@ int nfs_start_grace(nfs_grace_start_t *gsp)
 		 * flag and nothing else. If not, then clear the change req
 		 * flag and flip the active bit.
 		 */
-		if ((old & GRACE_STATUS_COUNT_MASK) &
+		if ((old & GRACE_STATUS_COUNT_MASK) &&
 		    nfs_param.nfsv4_param.sticky_grace) {
 			pro = old | GRACE_STATUS_CHANGE_REQ;
 		} else {
@@ -504,6 +505,34 @@ int nfs_recovery_get_nodeid(char **pnodeid)
 	return rc;
 }
 
+/**
+ * @brief Invokes FSAL specific reclaim capabilities
+ *
+ * If the FSAL need to reclaim the capabilities from the failed node/client
+ * then call this function appropriately
+ */
+int nfs_recovery_fsal_reclaim_client(char *nodeid)
+{
+	/* Module iterator */
+	struct glist_head *mi = NULL;
+	/* Next module */
+	struct glist_head *mn = NULL;
+
+	glist_for_each_safe(mi, mn, &fsal_list) {
+		/* The module to call client reclaim */
+		struct fsal_module *m =
+			glist_entry(mi, struct fsal_module, fsals);
+		/* skip MDCACHE & PSEUDO FSALs */
+		if ((strcmp("MDCACHE", m->name) == 0) ||
+		    (strcmp("PSEUDO", m->name) == 0))
+			continue;
+		LogEvent(COMPONENT_STATE, "Calling client reclaim for FSAL %s",
+			 m->name);
+		m->m_ops.fsal_reclaim_client(m, nodeid);
+	}
+	return 0;
+}
+
 void nfs_try_lift_grace(void)
 {
 	bool in_grace = true;
@@ -605,28 +634,28 @@ void nfs_wait_for_grace_enforcement(void)
 {
 	nfs_grace_start_t gsp = { .event = EVENT_JUST_GRACE };
 
-	pthread_mutex_lock(&enforcing_mutex);
+	PTHREAD_MUTEX_lock(&enforcing_mutex);
 	nfs_try_lift_grace();
 	while (nfs_in_grace() && !nfs_grace_enforcing()) {
 		struct timespec timeo = { .tv_sec = time(NULL) + 5,
 					  .tv_nsec = 0 };
 
-		pthread_cond_timedwait(&enforcing_cond, &enforcing_mutex,
+		PTHREAD_COND_timedwait(&enforcing_cond, &enforcing_mutex,
 				       &timeo);
 
-		pthread_mutex_unlock(&enforcing_mutex);
+		PTHREAD_MUTEX_unlock(&enforcing_mutex);
 		nfs_start_grace(&gsp);
 		nfs_try_lift_grace();
-		pthread_mutex_lock(&enforcing_mutex);
+		PTHREAD_MUTEX_lock(&enforcing_mutex);
 	}
-	pthread_mutex_unlock(&enforcing_mutex);
+	PTHREAD_MUTEX_unlock(&enforcing_mutex);
 }
 
 void nfs_notify_grace_waiters(void)
 {
-	pthread_mutex_lock(&enforcing_mutex);
-	pthread_cond_broadcast(&enforcing_cond);
-	pthread_mutex_unlock(&enforcing_mutex);
+	PTHREAD_MUTEX_lock(&enforcing_mutex);
+	PTHREAD_COND_broadcast(&enforcing_cond);
+	PTHREAD_MUTEX_unlock(&enforcing_mutex);
 }
 
 static pthread_cond_t norefs_cond;
@@ -634,17 +663,18 @@ static pthread_mutex_t norefs_mutex;
 
 void nfs_wait_for_grace_norefs(void)
 {
-	pthread_mutex_lock(&norefs_mutex);
+	PTHREAD_MUTEX_lock(&norefs_mutex);
 	struct timespec timeo = { .tv_sec = time(NULL) + 5, .tv_nsec = 0 };
-	pthread_cond_timedwait(&norefs_cond, &norefs_mutex, &timeo);
-	pthread_mutex_unlock(&norefs_mutex);
+
+	PTHREAD_COND_timedwait(&norefs_cond, &norefs_mutex, &timeo);
+	PTHREAD_MUTEX_unlock(&norefs_mutex);
 }
 
 void nfs_notify_grace_norefs_waiters(void)
 {
-	pthread_mutex_lock(&norefs_mutex);
-	pthread_cond_broadcast(&norefs_cond);
-	pthread_mutex_unlock(&norefs_mutex);
+	PTHREAD_MUTEX_lock(&norefs_mutex);
+	PTHREAD_COND_broadcast(&norefs_cond);
+	PTHREAD_MUTEX_unlock(&norefs_mutex);
 }
 
 /**
@@ -679,12 +709,24 @@ static bool check_clid(nfs_client_id_t *clientid, clid_entry_t *clid_ent)
 {
 	bool ret = false;
 
-	LogDebug(COMPONENT_CLIENTID, "compare %s to %s",
-		 clientid->cid_recov_tag, clid_ent->cl_name);
+	LogDebug(COMPONENT_CLIENTID, "compare %s to: %s reclaim complete %d",
+		 clientid->cid_recov_tag, clid_ent->cl_name,
+		 clid_ent->cl_reclaim_complete);
 
+	/**
+	 * If the clid_ent didn't reclaim completely before this grace period,
+	 * It may reclaim states in an questionable way during this period,
+	 * which may lead to erroneously states reclaim. We don't allow them
+	 * to reclaim states here. See RFC 8881 Section 8.4.3 for details.
+	 */
 	if (clientid->cid_recov_tag &&
-	    !strncmp(clientid->cid_recov_tag, clid_ent->cl_name, PATH_MAX))
-		ret = true;
+	    !strncmp(clientid->cid_recov_tag, clid_ent->cl_name, PATH_MAX)) {
+		/* The enforcement works on NFSv4.1 and higher versions. */
+		if (clientid->cid_minorversion > 0)
+			ret = clid_ent->cl_reclaim_complete;
+		else
+			ret = true;
+	}
 
 	return ret;
 }
@@ -714,8 +756,7 @@ void nfs4_chk_clid_impl(nfs_client_id_t *clientid, clid_entry_t **clid_ent_arg)
 	 * find it, mark it to allow reclaims.
 	 */
 	PTHREAD_MUTEX_lock(&clientid->cid_mutex);
-	glist_for_each(node, &clid_list)
-	{
+	glist_for_each(node, &clid_list) {
 		clid_ent = glist_entry(node, clid_entry_t, cl_list);
 		if (check_clid(clientid, clid_ent)) {
 			if (isDebug(COMPONENT_CLIENTID)) {
@@ -746,6 +787,15 @@ void nfs4_chk_clid(nfs_client_id_t *clientid)
 	PTHREAD_MUTEX_unlock(&grace_mutex);
 }
 
+void nfs41_reclaim_complete_clid(nfs_client_id_t *clientid)
+{
+	if (recovery_backend->reclaim_complete) {
+		PTHREAD_MUTEX_lock(&clientid->cid_mutex);
+		recovery_backend->reclaim_complete(clientid);
+		PTHREAD_MUTEX_unlock(&clientid->cid_mutex);
+	}
+}
+
 /**
  * @brief Load clients for recovery
  *
@@ -830,8 +880,8 @@ const char *recovery_backend_str(enum recovery_backend recovery_backend)
  */
 int nfs4_recovery_init(void)
 {
-	LogInfo(COMPONENT_CLIENTID, "Recovery Backend Init for %s",
-		recovery_backend_str(nfs_param.nfsv4_param.recovery_backend));
+	LogEvent(COMPONENT_CLIENTID, "Recovery Backend Init for %s",
+		 recovery_backend_str(nfs_param.nfsv4_param.recovery_backend));
 
 	switch (nfs_param.nfsv4_param.recovery_backend) {
 	case RECOVERY_BACKEND_FS:
@@ -930,9 +980,10 @@ bool nfs4_check_deleg_reclaim(nfs_client_id_t *clid, nfs_fh4 *fhandle)
 	struct glist_head *node;
 	rdel_fh_t *rfh_entry;
 	clid_entry_t *clid_ent;
-	int __attribute__((unused)) b64ret;
 	bool retval = true;
 
+	int __attribute__((unused)) b64ret;
+
 	/* Convert nfs_fh4_val into base64 encoded string */
 	b64ret = base64url_encode(fhandle->nfs_fh4_val, fhandle->nfs_fh4_len,
 				  rhdlstr, sizeof(rhdlstr));
@@ -941,8 +992,7 @@ bool nfs4_check_deleg_reclaim(nfs_client_id_t *clid, nfs_fh4 *fhandle)
 	PTHREAD_MUTEX_lock(&grace_mutex);
 	nfs4_chk_clid_impl(clid, &clid_ent);
 	if (clid_ent) {
-		glist_for_each(node, &clid_ent->cl_rfh_list)
-		{
+		glist_for_each(node, &clid_ent->cl_rfh_list) {
 			rfh_entry = glist_entry(node, rdel_fh_t, rdfh_list);
 			assert(rfh_entry != NULL);
 			if (!strcmp(rhdlstr, rfh_entry->rdfh_handle_str)) {
@@ -964,12 +1014,10 @@ bool nfs4_check_deleg_reclaim(nfs_client_id_t *clid, nfs_fh4 *fhandle)
 /**
  * @brief Release NLM state
  */
-static void nlm_releasecall(struct fridgethr_context *ctx)
+static void nlm_release(state_nsm_client_t *nsm_cp)
 {
-	state_nsm_client_t *nsm_cp;
 	state_status_t err;
 
-	nsm_cp = ctx->arg;
 	err = state_nlm_notify(nsm_cp, false, 0);
 	if (err != STATE_SUCCESS)
 		LogDebug(COMPONENT_STATE, "state_nlm_notify failed with %d",
@@ -978,52 +1026,6 @@ static void nlm_releasecall(struct fridgethr_context *ctx)
 }
 #endif /* _USE_NLM */
 
-void extractv4(char *ipv6, char *ipv4, size_t size)
-{
-	char *token, *saveptr;
-	char *delim = ":";
-
-	token = strtok_r(ipv6, delim, &saveptr);
-	while (token != NULL) {
-		/* IPv4 delimiter is '.' */
-		if (strchr(token, '.') != NULL) {
-			(void)strlcpy(ipv4, token, size);
-			return;
-		}
-		token = strtok_r(NULL, delim, &saveptr);
-	}
-	/* failed, copy a null string */
-	ipv4[0] = '\0';
-}
-
-bool ip_str_match(char *release_ip, char *server_ip)
-{
-	bool ripv6, sipv6;
-	char ipv4[SOCK_NAME_MAX];
-
-	/* IPv6 delimiter is ':' */
-	ripv6 = (strchr(release_ip, ':') != NULL);
-	sipv6 = (strchr(server_ip, ':') != NULL);
-
-	if (ripv6) {
-		if (sipv6)
-			return !strcmp(release_ip, server_ip);
-		else {
-			/* extract v4 addr from release_ip*/
-			extractv4(release_ip, ipv4, sizeof(ipv4));
-			return !strcmp(ipv4, server_ip);
-		}
-	} else {
-		if (sipv6) {
-			/* extract v4 addr from server_ip*/
-			extractv4(server_ip, ipv4, sizeof(ipv4));
-			return !strcmp(ipv4, release_ip);
-		}
-	}
-	/* Both are ipv4 addresses */
-	return !strcmp(release_ip, server_ip);
-}
-
 /**
  * @brief Release all NLM state
  */
@@ -1036,8 +1038,7 @@ static void nfs_release_nlm_state(char *release_ip)
 	struct rbt_head *head_rbt;
 	struct rbt_node *pn;
 	struct hash_data *pdata;
-	state_status_t state_status;
-	char serverip[SOCK_NAME_MAX];
+	sockaddr_t release_addr;
 	int i;
 
 	if (!nfs_param.core_param.enable_NLM)
@@ -1047,29 +1048,29 @@ static void nfs_release_nlm_state(char *release_ip)
 
 	cancel_all_nlm_blocked();
 
+	ip_str_to_sockaddr(release_ip, &release_addr);
+
 	/* walk the client list and call state_nlm_notify */
 	for (i = 0; i < ht->parameter.index_size; i++) {
-		PTHREAD_RWLOCK_wrlock(&ht->partitions[i].ht_lock);
 		head_rbt = &ht->partitions[i].rbt;
+restart:
+		LogDebug(COMPONENT_STATE, "Trying lock on %p",
+			 &ht->partitions[i].ht_lock);
+		PTHREAD_RWLOCK_wrlock(&ht->partitions[i].ht_lock);
 		/* go through all entries in the red-black-tree */
 		RBT_LOOP(head_rbt, pn)
 		{
 			pdata = RBT_OPAQ(pn);
 			nlm_cp = (state_nlm_client_t *)pdata->val.addr;
 
-			if (sprint_sockip(&nlm_cp->slc_server_addr, serverip,
-					  sizeof(serverip)) &&
-			    ip_str_match(release_ip, serverip)) {
+			if (cmp_sockaddr(&release_addr,
+					 &nlm_cp->slc_server_addr, true)) {
 				nsm_cp = nlm_cp->slc_nsm_client;
 				inc_nsm_client_ref(nsm_cp);
-				state_status = fridgethr_submit(
-					state_async_fridge, nlm_releasecall,
-					nsm_cp);
-				if (state_status != STATE_SUCCESS) {
-					dec_nsm_client_ref(nsm_cp);
-					LogCrit(COMPONENT_STATE,
-						"failed to submit nlm release thread ");
-				}
+				PTHREAD_RWLOCK_unlock(
+					&ht->partitions[i].ht_lock);
+				nlm_release(nsm_cp);
+				goto restart;
 			}
 			RBT_INCREMENT(pn);
 		}
@@ -1078,25 +1079,23 @@ static void nfs_release_nlm_state(char *release_ip)
 #endif /* _USE_NLM */
 }
 
-static int ip_match(char *ip, nfs_client_id_t *cid)
+static int ip_match(sockaddr_t *ip, nfs_client_id_t *cid)
 {
-	char *haystack;
-	char *value = cid->cid_client_record->cr_client_val;
-	int len = cid->cid_client_record->cr_client_val_len;
+	int rc;
+	sockaddr_t *saddr = &cid->cid_client_record->cr_server_addr;
 
-	LogDebug(COMPONENT_STATE, "NFS Server V4 match ip %s with (%.*s)", ip,
-		 len, value);
-
-	if (strlen(ip) == 0) /* No IP all are matching */
-		return 1;
-
-	haystack = alloca(len + 1);
-	memcpy(haystack, value, len);
-	haystack[len] = '\0';
-	if (strstr(haystack, ip) != NULL)
-		return 1;
-
-	return 0; /* no match */
+	if (isFullDebug(COMPONENT_STATE)) {
+		char addr1[SOCK_NAME_MAX] = "\0";
+		char addr2[SOCK_NAME_MAX] = "\0";
+		struct display_buffer db1 = { sizeof(addr1), addr1, addr1 };
+		struct display_buffer db2 = { sizeof(addr2), addr2, addr2 };
+		display_sockaddr_port(&db1, ip, true);
+		display_sockaddr_port(&db2, saddr, true);
+		LogDebug(COMPONENT_STATE, "Match %s with %s", addr1, addr2);
+	}
+	rc = cmp_sockaddr(ip, saddr, true);
+	LogDebug(COMPONENT_STATE, "Match ret=%d", rc);
+	return rc;
 }
 
 /*
@@ -1113,8 +1112,10 @@ static void nfs_release_v4_clients(char *ip)
 	nfs_client_id_t *cp;
 	nfs_client_record_t *recp;
 	int i;
+	sockaddr_t ip_saddr;
 
 	LogEvent(COMPONENT_STATE, "NFS Server V4 recovery release ip %s", ip);
+	ip_str_to_sockaddr(ip, &ip_saddr);
 
 	/* go through the confirmed clients looking for a match */
 	for (i = 0; i < ht->parameter.index_size; i++) {
@@ -1131,7 +1132,7 @@ restart:
 			cp = (nfs_client_id_t *)pdata->val.addr;
 			PTHREAD_MUTEX_lock(&cp->cid_mutex);
 			if ((cp->cid_confirmed == CONFIRMED_CLIENT_ID) &&
-			    ip_match(ip, cp)) {
+			    ip_match(&ip_saddr, cp)) {
 				inc_client_id_ref(cp);
 
 				/* client_record is always non-NULL. */
