@@ -50,6 +50,7 @@
 #include "nfs4.h"
 #include "gsh_recovery.h"
 #include "gsh_rpc.h"
+#include "pwnam_wrappers.h"
 
 /**
  * @brief An enumeration of protocols in the NFS family
@@ -247,9 +248,12 @@ typedef enum protos {
 #define NFS_RDMA_ENABLE_FOR_NFSV41 0x00000004
 #define NFS_RDMA_ENABLE_FOR_NFSV42 0x00000008
 
-#define NFS_RDMA_ENABLE_FOR_ALL \
-	(NFS_RDMA_ENABLE_FOR_NFSV3 | NFS_RDMA_ENABLE_FOR_NFSV40)
-#define NFS_RDMA_ENABLE_BY_DEFAULT NFS_RDMA_ENABLE_FOR_NFSV40
+#define NFS_RDMA_ENABLE_FOR_ALL                                   \
+	(NFS_RDMA_ENABLE_FOR_NFSV3 | NFS_RDMA_ENABLE_FOR_NFSV40 | \
+	 NFS_RDMA_ENABLE_FOR_NFSV41 | NFS_RDMA_ENABLE_FOR_NFSV42)
+#define NFS_RDMA_ENABLE_BY_DEFAULT                                 \
+	(NFS_RDMA_ENABLE_FOR_NFSV40 | NFS_RDMA_ENABLE_FOR_NFSV41 | \
+	 NFS_RDMA_ENABLE_FOR_NFSV42)
 #endif
 
 typedef struct nfs_core_param {
@@ -519,6 +523,9 @@ typedef struct nfs_core_param {
 	*/
 	uint32_t malloc_trim_minthreshold;
 #ifdef USE_MONITORING
+	/** Monitoring IP address. Monitoring service will listen on
+	 * <monitoring_addr>:<monitoring_port> */
+	sockaddr_t monitoring_addr;
 	/** Monitoring port number. */
 	uint16_t monitoring_port;
 	/** Enable creating metrics labels on the fly based on client-ip,
@@ -527,6 +534,8 @@ typedef struct nfs_core_param {
 	 * performance.
 	*/
 	bool enable_dynamic_metrics;
+	/** Enable creating metrics and pushing to MONITORING IP address */
+	bool enable_metrics;
 #endif
 	/** if  Manage_Gids=True and group resolution fails,
 	 *  then use gid data from rpc request */
@@ -625,6 +634,11 @@ typedef struct nfs_version4_parameter {
 	/** The eir_server_owner. Defaults to NULL and is settable
 	    with server_owner. */
 	char *server_owner;
+	/** When true, Ganesha will operate in virtual server mode, where it
+	 *  makes each server IP address appear to clients as a separate
+	 *  server.
+	 */
+	bool virtual_server;
 	/** This config param is deprecated. Use `domainname` defined
 	    in `directory_services_param` struct. */
 	char *domainname;
@@ -656,12 +670,16 @@ typedef struct nfs_version4_parameter {
 	bool allow_delegations;
 	/** Delay after which server will retry a recall in case of failures */
 	uint32_t deleg_recall_retry_delay;
+	/** support for OPEN4_RESULT_PRESERVE_UNLINKED */
+	bool preserve_unlinked;
 	/** Whether this a pNFS MDS server. Defaults to false */
 	bool pnfs_mds;
 	/** Whether this a pNFS DS server. Defaults to false */
 	bool pnfs_ds;
 	/** Recovery backend */
 	enum recovery_backend recovery_backend;
+	/** Whether Recovery backend is IP based */
+	bool recovery_backend_ipbased;
 	/** List of supported NFSV4 minor versions */
 	unsigned int minor_versions;
 	/** Number of allowed slots in the 4.1 slot table */
@@ -716,9 +734,17 @@ typedef struct directory_services_param {
 	uint32_t negative_cache_groups_max_count;
 	/** Cache reaping interval in seconds for idmapped users and groups */
 	int64_t cache_reaping_interval;
+	/** Max number of groups we allow a user to be a member of */
+	uint32_t max_groups_membership;
 	/** Whether to use fully qualified names for idmapping with pw-utils.
 	    Defaults to false. */
 	bool pwutils_use_fully_qualified_names;
+	/** What Pwnam implementation to use */
+	pwnam_implementation_t pwnam_implementation;
+	/** SSSD implementation timeout to use */
+	uint32_t sssd_implementation_timeout;
+	/** SSSD implementation skip SSSD cache */
+	bool sssd_implementation_skip_cache;
 } directory_services_param_t;
 
 /** @} */
