@@ -267,8 +267,7 @@ static inline size_t glist_length(struct glist_head *head)
 	size_t length = 0;
 	struct glist_head *dummy = NULL;
 
-	glist_for_each(dummy, head)
-	{
+	glist_for_each(dummy, head) {
 		++length;
 	}
 	return length;
@@ -280,13 +279,13 @@ static inline size_t glist_length(struct glist_head *head)
 		(type *)((char *)__mptr - offsetof(type, member));  \
 	})
 
-#define glist_first_entry(head, type, member)                                \
-	((head)->next != (head) ? container_of((head)->next, type, member) : \
-				  NULL)
+#define glist_first_entry(head, type, member)                              \
+	((head)->next != (head) ? container_of((head)->next, type, member) \
+				: NULL)
 
-#define glist_last_entry(head, type, member)                                 \
-	((head)->prev != (head) ? container_of((head)->prev, type, member) : \
-				  NULL)
+#define glist_last_entry(head, type, member)                               \
+	((head)->prev != (head) ? container_of((head)->prev, type, member) \
+				: NULL)
 
 #define glist_entry(node, type, member) container_of(node, type, member)
 
@@ -299,14 +298,14 @@ static inline size_t glist_length(struct glist_head *head)
 	     node = noden, noden = node->next)
 
 /* Return the next entry in the list after node if any. */
-#define glist_next_entry(head, type, member, node)                           \
-	((node)->next != (head) ? container_of((node)->next, type, member) : \
-				  NULL)
+#define glist_next_entry(head, type, member, node)                         \
+	((node)->next != (head) ? container_of((node)->next, type, member) \
+				: NULL)
 
 /* Return the previous entry in the list after node if any. */
-#define glist_prev_entry(head, type, member, node)                           \
-	((node)->prev != (head) ? container_of((node)->prev, type, member) : \
-				  NULL)
+#define glist_prev_entry(head, type, member, node)                         \
+	((node)->prev != (head) ? container_of((node)->prev, type, member) \
+				: NULL)
 
 static inline void glist_insert_sorted(struct glist_head *head,
 				       struct glist_head *elt,
@@ -318,8 +317,7 @@ static inline void glist_insert_sorted(struct glist_head *head,
 		glist_add_tail(head, elt);
 		return;
 	}
-	glist_for_each(next, head)
-	{
+	glist_for_each(next, head) {
 		if (compare(next, elt) > 0)
 			break;
 	}
