@@ -72,9 +72,16 @@ extern struct global_export_perms export_opt;
 
 #define GSS_DEFINE_LEN_TEMP 255
 
+enum client_ha_proxy_protocol_type {
+	CLIENT_ENTRY_HA_PROXY_PROTOCOL_WITHOUT = 0,
+	CLIENT_ENTRY_HA_PROXY_PROTOCOL_WITH = 1,
+	CLIENT_ENTRY_HA_PROXY_PROTOCOL_ANY = 2
+};
+
 struct exportlist_client_entry {
 	struct base_client_entry client_entry;
 	struct export_perms client_perms; /*< Available mount options */
+	enum client_ha_proxy_protocol_type ha_proxy_protocol_type;
 };
 
 /* Constants for export options masks */
@@ -191,7 +198,8 @@ struct exportlist_client_entry {
 #define EXPORT_OPTION_PROTO_DEFAULTS (EXPORT_OPTION_NFSV3 | EXPORT_OPTION_NFSV4)
 #define EXPORT_OPTION_TRANSPORTS \
 	(EXPORT_OPTION_UDP | EXPORT_OPTION_TCP | EXPORT_OPTION_RDMA)
-#define EXPORT_OPTION_XPORT_DEFAULTS (EXPORT_OPTION_UDP | EXPORT_OPTION_TCP)
+#define EXPORT_OPTION_XPORT_DEFAULTS \
+	(EXPORT_OPTION_UDP | EXPORT_OPTION_TCP | EXPORT_OPTION_RDMA)
 
 #define EXPORT_OPTION_READ_DELEG 0x10000000 /*< Enable read delegations */
 #define EXPORT_OPTION_WRITE_DELEG 0x20000000 /*< Using write delegations */
