@@ -208,12 +208,12 @@ struct auth_stats {
 		STAT_TYPE_NFSV40 STAT_TYPE_NFSV41 STAT_TYPE_NFSV42 STAT_TYPE_9P \
 	")"
 
-#define EXPORT_CONTAINER "(" TYPE_ID TYPE_STRING PROTOCOLS_CONTAINER "(tt))"
+#define EXPORT_CONTAINER "(" TYPE_ID TYPE_STRING PROTOCOLS_CONTAINER "t(tt))"
 
 #define STATE_STATS_REPLY "(ststst)"
 
 #define CLIENT_CONTAINER \
-	"(" TYPE_STRING PROTOCOLS_CONTAINER STATE_STATS_REPLY "(tt))"
+	"(" TYPE_STRING PROTOCOLS_CONTAINER "t" STATE_STATS_REPLY "(tt))"
 
 #define EXPORTS_REPLY \
 	{ .name = "exports", .type = "a" EXPORT_CONTAINER, .direction = "out" }
